@@ -1,49 +1,50 @@
-#' Connect a local repo with GitHub.
+#' Connect a local repo with GitHub
 #'
-#' `use_github()` requires that your package have a git repository,
-#' which you can create with [use_git()], if needed.
-#' `use_github()` then sets up appropriate git remotes and syncs.
-#' `use_github_links()` populates the `URL` and `BugReports`
-#' fields with appropriate links (unless they already exist).
+#' @description
+#' `use_github()` takes a local project, creates an associated repo on GitHub,
+#' adds it to your local repo as the `origin` remote, and makes an initial push
+#' to synchronize. `use_github()` requires that your project already be a Git
+#' repository, which you can accomplish with [use_git()], if needed.
+#'
+#' `use_github_links()` populates the `URL` and `BugReports` fields of a
+#' GitHub-using R package with appropriate links (unless they already exist).
 #'
 #' @section Authentication:
+#' A new GitHub repo will be created via the GitHub API, therefore you must
+#' make a [GitHub personal access token
+#' (PAT)](https://github.com/settings/tokens) available. You can either
+#' provide this directly via the `auth_token` argument or store it in an
+#' environment variable. Use [browse_github_pat()] to get help obtaining and
+#' storing your PAT. See [gh::gh_whoami()] for even more detail.
 #'
-#'   A new GitHub repo will be created via the GitHub API, therefore you must
-#'   provide a GitHub personal access token (PAT) via the argument
-#'   `auth_token`, which defaults to the value of the `GITHUB_PAT`
-#'   environment variable. Obtain a PAT from
-#'   \url{https://github.com/settings/tokens}. The "repo" scope is required
-#'   which is one of the default scopes for a new PAT.
+#' The argument `protocol` reflects how you wish to authenticate with GitHub
+#' for this repo in the long run. This determines the form of the URL for the
+#' `origin` remote:
+#'   * `protocol = "ssh"`: `git@@github.com:<USERNAME>/<REPO>.git`
+#'   * `protocol = "https"`: `https://github.com/<USERNAME>/<REPO>.git`
 #'
-#'   The argument `protocol` reflects how you wish to authenticate with
-#'   GitHub for this repo in the long run. For either `protocol`, a remote
-#'   named "origin" is created, an initial push is made using the specified
-#'   `protocol`, and a remote tracking branch is set. The URL of the
-#'   "origin" remote has the form `git@@github.com:<USERNAME>/<REPO>.git`
-#'   (`protocol = "ssh"`, the default) or
-#'   `https://github.com/<USERNAME>/<REPO>.git` (\code{protocol =
-#'   "https"}). For `protocol = "ssh"`, it is assumed that public and
-#'   private keys are in the default locations, `~/.ssh/id_rsa.pub` and
-#'   `~/.ssh/id_rsa`, respectively, and that `ssh-agent` is configured
-#'   to manage any associated passphrase.  Alternatively, specify a
-#'   [git2r::cred_ssh_key()] object via the `credentials`
-#'   parameter.
+#' For `protocol = "ssh"`, it is assumed that public and private keys are in the
+#' default locations, `~/.ssh/id_rsa.pub` and `~/.ssh/id_rsa`, respectively, and
+#' that `ssh-agent` is configured to manage any associated passphrase.
+#' Alternatively, specify a [git2r::cred_ssh_key()] object via the `credentials`
+#' parameter. Read more about ssh setup in [Happy
+#' Git](http://happygitwithr.com/ssh-keys.html), especially the [troubleshooting
+#' section](http://happygitwithr.com/ssh-keys.html#ssh-troubleshooting).
 #'
 #' @inheritParams use_git
 #' @param organisation If supplied, the repo will be created under this
 #'   organisation. You must have access to create repositories.
 #' @param auth_token Provide a personal access token (PAT) from
-#'   \url{https://github.com/settings/tokens}. If `NULL`, will use the
-#'   `GITHUB_PAT` environment variable.
+#'   <https://github.com/settings/tokens>. If `NULL`, will use the logic
+#'   described in [gh::gh_whoami()] to look for a token stored in an environment
+#'   variable. Use [browse_github_pat()] to help set up your PAT.
 #' @param private If `TRUE`, creates a private repository.
 #' @param host GitHub API host to use. Override with the endpoint-root for your
 #'   GitHub enterprise instance, for example,
-#'   "https://github.hostname.com/api/v3". You can set this globally using
-#'   the `GITHUB_API_URL` env var.
+#'   "https://github.hostname.com/api/v3"
 #' @param protocol transfer protocol, either "ssh" (the default) or "https"
-#' @param credentials A [git2r::cred_ssh_key()] specifying specific
-#' ssh credentials or NULL for default ssh key and ssh-agent behaviour.
-#' Default is NULL.
+#' @param credentials A [git2r::cred_ssh_key()] specifying specific ssh
+#'   credentials or `NULL` for default ssh key and ssh-agent behaviour.
 #' @export
 #' @examples
 #' \dontrun{
@@ -62,12 +63,7 @@ use_github <- function(organisation = NULL,
                        credentials = NULL,
                        auth_token = NULL,
                        host = NULL) {
-  if (!uses_git()) {
-    stop(
-      "Please call ", code("use_git()"), " before ",
-      code("use_github()"), ".", call. = FALSE
-    )
-  }
+  check_uses_git()
 
   if (uses_github(proj_get())) {
     done("GitHub is already initialized")
@@ -149,7 +145,9 @@ use_github <- function(organisation = NULL,
     cred <- git2r::cred_user_pass("EMAIL", auth_token)
     git2r::push(r, "origin", "refs/heads/master", credentials = cred)
   }
-  git2r::branch_set_upstream(git2r::head(r), "origin/master")
+  ## utils::head instead of git2r::head due to the conversion of git2r's head
+  ## from S4 --> S3 method in v0.21.0 --> 0.21.0.9000
+  git2r::branch_set_upstream(utils::head(r), "origin/master")
 
   view_url(create$html_url)
 
@@ -177,6 +175,50 @@ use_github_links <- function(auth_token = NULL,
   invisible()
 }
 
+#' Create a GitHub personal access token
+#'
+#' Opens a browser window to the GitHub page where you can generate a [Personal
+#' Access
+#' Token](https://help.github.com/articles/creating-a-personal-access-token-for-the-command-line).
+#' Make sure you have signed up for a free [GitHub.com](https://github.com/)
+#' account and that you are signed in. Click "Generate token" after you have
+#' verified the scopes. Copy the token right away! You probably want to store it
+#' in `.Renviron` as the `GITHUB_PAT` environment variable. [edit_r_environ()]
+#' can help you do that. Use [gh::gh_whoami()] to get information on an existing
+#' token.
+#'
+#' @param scopes Character vector of token permissions. These are just defaults
+#'   that will be pre-selected in the web form. You can select the final values
+#'   on the GitHub page. Read more about GitHub API scopes at
+#'   <https://developer.github.com/apps/building-oauth-apps/scopes-for-oauth-apps/>.
+#'
+#' @param description Short description or nickname for the token. It helps you
+#'   distinguish various tokens on GitHub.
+#' @inheritParams use_github
+#' @export
+#' @examples
+#' \dontrun{
+#' browse_github_pat()
+#' ## COPY THE PAT!!!
+#' ## almost certainly to be followed by ...
+#' edit_r_environ()
+#' ## which helps you store the PAT as an env var
+#' }
+browse_github_pat <- function(scopes = c("repo", "gist"),
+                              description = "R:GITHUB_PAT",
+                              host = "https://github.com") {
+  scopes <- collapse(scopes, ",")
+  url <- sprintf(
+    "%s/settings/tokens/new?scopes=%s&description=%s",
+    host, scopes, description
+  )
+  view_url(url)
+  todo(
+    "Call ", code("edit_r_environ()"), " to open ", value(".Renviron"),
+    ", and store your PAT with a line like:\n", "GITHUB_PAT=xxxyyyzzz"
+  )
+  todo("Make sure ", value(".Renviron"), " ends with a newline!")
+}
 
 uses_github <- function(base_path = proj_get()) {
   tryCatch({
@@ -188,7 +230,7 @@ uses_github <- function(base_path = proj_get()) {
 
 check_uses_github <- function(base_path = proj_get()) {
   if (uses_github(base_path)) {
-    return()
+    return(invisible())
   }
 
   stop(
@@ -197,3 +239,10 @@ check_uses_github <- function(base_path = proj_get()) {
     call. = FALSE
   )
 }
+
+## use from gh when/if exported
+## https://github.com/r-lib/gh/issues/74
+gh_token <- function() {
+  token <- Sys.getenv('GITHUB_PAT', "")
+  if (token == "") Sys.getenv("GITHUB_TOKEN", "") else token
+}
