@@ -15,16 +15,41 @@
 #' * `use_tidy_eval()`: imports a standard set of helpers to facilitate
 #'   programming with the tidy eval toolkit.
 #'
+#' * `use_tidy_style()`: styles source code according to the [tidyverse style
+#' guide](http://style.tidyverse.org). This function will overwrite files! See
+#' below for usage advice.
+#'
 #' * `use_tidy_versions()`: pins all dependencies to require at least
 #'   the currently installed version.
 #'
-#' * `use_tidy_contributing()`: creates tidyverse contributing guidelines from
-#'    tidy_contributing template.
+#' * `use_tidy_contributing()`: adds standard tidyverse contributing guidelines.
 #'
-#' * `use_tidy_issue_template()`: creates a standard tidyverse issue template.
+#' * `use_tidy_issue_template()`: adds a standard tidyverse issue template.
 #'
-#' * `use_tidy_support()`: creates support resources document for GitHub repo
-#'    using SUPPORT.md.
+#' * `use_tidy_support()`: adds a standard description of support resources for
+#'    the tidyverse.
+#'
+#' * `use_tidy_coc()`: equivalent to `use_code_of_conduct()`, but puts the
+#'    document in a `.github/` subdirectory.
+#'
+#' * `use_tidy_github()`: convenience wrapper that calls
+#' `use_tidy_contributing()`, `use_tidy_issue_template()`, `use_tidy_support()`,
+#' `use_tidy_coc()`.
+#'
+#' @section `use_tidy_style()`:
+#' Uses the [styler package](http://styler.r-lib.org) package to style all code
+#' in a package, project, or directory, according to the [tidyverse style
+#' guide](http://style.tidyverse.org).
+#'
+#' **Warning:** This function will overwrite files! It is strongly suggested to
+#' only style files that are under version control or to first create a backup
+#' copy.
+#'
+#' Invisibly returns a data frame with one row per file, that indicates whether
+#' styling caused a change.
+#'
+#' @param strict Boolean indicating whether or not a strict version of styling
+#'   should be applied. See [styler::tidyverse_style()] for details.
 #'
 #' @name tidyverse
 NULL
@@ -124,21 +149,15 @@ use_tidy_eval <- function() {
 #' @export
 #' @rdname tidyverse
 use_tidy_contributing <- function() {
-  check_uses_travis()
-
-  gh <- gh::gh_tree_remote(proj_get())
-  travis_url <- file.path("https://travis-ci.org", gh$username, gh$repo)
-  github_url <- file.path("https://github.com", gh$username, gh$repo)
+  check_uses_github()
 
+  use_directory(".github", ignore = TRUE)
   use_template(
-    "tidy_contributing.md",
-    "CONTRIBUTING.md",
+    "tidy-contributing.md",
+    ".github/CONTRIBUTING.md",
     data = list(
-      package = project_name(),
-      github_url = github_url,
-      travis_url = travis_url
-    ),
-    ignore = TRUE
+      package = project_name()
+    )
   )
 }
 
@@ -148,10 +167,10 @@ use_tidy_contributing <- function() {
 use_tidy_issue_template <- function() {
   check_uses_github()
 
+  use_directory(".github", ignore = TRUE)
   use_template(
-    "ISSUE_TEMPLATE.md",
-    "ISSUE_TEMPLATE.md",
-    ignore = TRUE
+    "tidy-issue.md",
+    ".github/ISSUE_TEMPLATE.md"
   )
 }
 
@@ -161,9 +180,57 @@ use_tidy_issue_template <- function() {
 use_tidy_support <- function() {
   check_uses_github()
 
+  use_directory(".github", ignore = TRUE)
   use_template(
-    "SUPPORT.md",
-    data = list(package = project_name()),
-    ignore = TRUE
+    "tidy-support.md",
+    ".github/SUPPORT.md",
+    data = list(package = project_name())
   )
 }
+
+
+#' @export
+#' @rdname tidyverse
+use_tidy_coc <- function() {
+  check_uses_github()
+
+  use_directory(".github", ignore = TRUE)
+  use_template(
+    "CODE_OF_CONDUCT.md",
+    ".github/CODE_OF_CONDUCT.md"
+  )
+
+  todo("Don't forget to describe the code of conduct in your README.md:")
+  code_block(
+    "Please note that this project is released with a [Contributor Code of Conduct](.github/CODE_OF_CONDUCT.md).",
+    "By participating in this project you agree to abide by its terms."
+  )
+}
+
+#' @export
+#' @rdname tidyverse
+use_tidy_github <- function() {
+  use_tidy_contributing()
+  use_tidy_issue_template()
+  use_tidy_support()
+  use_tidy_coc()
+}
+
+#' @export
+#' @rdname tidyverse
+use_tidy_style <- function(strict = TRUE) {
+  check_installed("styler")
+  check_uncommitted_changes()
+  if (is_package()) {
+    styled <- styler::style_pkg(proj_get(),
+                                style = styler::tidyverse_style, strict = strict
+    )
+  } else {
+    styled <- styler::style_dir(proj_get(),
+                                style = styler::tidyverse_style, strict = strict
+    )
+  }
+  cat_line()
+  done("Styled project according to the tidyverse style guide")
+  invisible(styled)
+}
