@@ -4,7 +4,3 @@
 .onLoad <- function(libname, pkgname) {
   backports::import(pkgname, "dir.exists")
 }
-
-.onAttach <- function(...) {
-  proj_set(".")
-}
